#!/bin/bash
cd /usr/src
clear
ls *.orig 2>/dev/null >/dev/null
if [ $? -eq 0 ] ; then
   echo "These files will be deleted by this script because they end in"
   echo ".orig - I will quit now, please rename them or move them before"
   echo "proceeding:"
   ls *.orig
   exit 1
fi
echo
echo "This will install the joliet patches to the kernel found"
echo "in /usr/src/linux.  NOTE:  This just applies the patch"
echo '(which is not as easy as it should be), you are expected'
echo "to be able to compile the kernel yourself after this..."
echo "To cancel, hit CTRL-C now..."
echo
sleep 10
echo
patch < joliet_fat32_nls_patch-0.2.7
rm *.orig
mv isofs.txt linux/Documentation/
mv joliet.c linux/fs/isofs/
mv vfatfs_syms.c linux/fs/vfat/
mv nls.h linux/include/linux
mv nls* linux/fs/
echo "Done."
echo
echo "When you configure your kernel, here are things you *must* do to"
echo "get Joliet working.  Otherwise, configure your kernel as usual..."
cat << __EOF__
DOS FAT fs support (CONFIG_FAT_FS) [Y/m/n/?] y
Unicode, native language support (CONFIG_NLS) [N/y/m/?] (NEW) y
NLS Codepage 437 (CONFIG_NLS_CODEPAGE_437) [N/y/m/?] (NEW) y
NLS Codepage 737 (CONFIG_NLS_CODEPAGE_737) [N/y/m/?] (NEW) n
NLS Codepage 775 (CONFIG_NLS_CODEPAGE_775) [N/y/m/?] (NEW) n
NLS Codepage 850 (CONFIG_NLS_CODEPAGE_850) [N/y/m/?] (NEW) n
NLS Codepage 852 (CONFIG_NLS_CODEPAGE_852) [N/y/m/?] (NEW) n
NLS Codepage 855 (CONFIG_NLS_CODEPAGE_855) [N/y/m/?] (NEW) n
NLS Codepage 857 (CONFIG_NLS_CODEPAGE_857) [N/y/m/?] (NEW) n
NLS Codepage 860 (CONFIG_NLS_CODEPAGE_860) [N/y/m/?] (NEW) n
NLS Codepage 861 (CONFIG_NLS_CODEPAGE_861) [N/y/m/?] (NEW) n
NLS Codepage 862 (CONFIG_NLS_CODEPAGE_862) [N/y/m/?] (NEW) n
NLS Codepage 863 (CONFIG_NLS_CODEPAGE_863) [N/y/m/?] (NEW) n
NLS Codepage 864 (CONFIG_NLS_CODEPAGE_864) [N/y/m/?] (NEW) n
NLS Codepage 865 (CONFIG_NLS_CODEPAGE_865) [N/y/m/?] (NEW) n
NLS Codepage 866 (CONFIG_NLS_CODEPAGE_866) [N/y/m/?] (NEW) n
NLS Codepage 869 (CONFIG_NLS_CODEPAGE_869) [N/y/m/?] (NEW) n
NLS Codepage 874 (CONFIG_NLS_CODEPAGE_874) [N/y/m/?] (NEW) n
NLS ISO 8859-1 (CONFIG_NLS_ISO8859_1) [N/y/m/?] (NEW) y
NLS ISO 8859-2 (CONFIG_NLS_ISO8859_2) [N/y/m/?] (NEW) n
NLS ISO 8859-3 (CONFIG_NLS_ISO8859_3) [N/y/m/?] (NEW) n
NLS ISO 8859-4 (CONFIG_NLS_ISO8859_4) [N/y/m/?] (NEW) n
NLS ISO 8859-5 (CONFIG_NLS_ISO8859_5) [N/y/m/?] (NEW) n
NLS ISO 8859-6 (CONFIG_NLS_ISO8859_6) [N/y/m/?] (NEW) n
NLS ISO 8859-7 (CONFIG_NLS_ISO8859_7) [N/y/m/?] (NEW) n
NLS ISO 8859-8 (CONFIG_NLS_ISO8859_8) [N/y/m/?] (NEW) n
NLS ISO 8859-9 (CONFIG_NLS_ISO8859_9) [N/y/m/?] (NEW) n
NLS KOI8-R (CONFIG_NLS_KOI8_R) [N/y/m/?] (NEW) n
MSDOS fs support (CONFIG_MSDOS_FS) [Y/m/n/?] y
VFAT (Windows-95) fs support (CONFIG_VFAT_FS) [N/y/m/?] y
ISO9660 cdrom filesystem support (CONFIG_ISO9660_FS) [Y/m/n/?] y

NOTE:  Answering 'm' instead of 'y' in any of the above will
probably stop Joliet support from working...

If you missed some of this, edit this shell script and scroll to the
bottom...
__EOF__

